*****************************************
The sherpa.plot.pylab_area_backend module
*****************************************

.. currentmodule:: sherpa.plot.pylab_area_backend

.. automodule:: sherpa.plot.pylab_area_backend

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      PylabErrorArea

Class Inheritance Diagram
=========================

.. inheritance-diagram::   PylabErrorArea
   :parts: 1
